@@ -1,26 +1,5 @@
-/*
-     This file is part of libmicrohttpd
-     (C) 2011 Christian Grothoff (and other contributing authors)
-
-     This library is free software; you can redistribute it and/or
-     modify it under the terms of the GNU Lesser General Public
-     License as published by the Free Software Foundation; either
-     version 2.1 of the License, or (at your option) any later version.
-
-     This library is distributed in the hope that it will be useful,
-     but WITHOUT ANY WARRANTY; without even the implied warranty of
-     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-     Lesser General Public License for more details.
-
-     You should have received a copy of the GNU Lesser General Public
-     License along with this library; if not, write to the Free Software
-     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-*/
-/**
- * @file post_example.c
- * @brief example for processing POST requests using libmicrohttpd
- * @author Christian Grothoff
- */
+/* Feel free to use this example code in any way
+   you see fit (Public Domain) */
 
 /* needed for asprintf */
 #define _GNU_SOURCE
