@@ -27,8 +27,10 @@
 
 /**
  * Size of on-stack buffer that we use for un-escaping of the value.
+ * We use a pretty small value to be nice to the stack on embedded
+ * systems.
  */
-#define XBUF_SIZE 1024
+#define XBUF_SIZE 512
 
 /**
  * States in the PP parser's state machine.
@@ -537,7 +539,7 @@ try_get_value (const char *buf, const char *key, char **destination)
         }
       if (spos[klen + 1] != '"')
         return;                 /* not quoted */
-      if (NULL == (endv = strstr (&spos[klen + 2], "\"")))
+      if (NULL == (endv = strchr (&spos[klen + 2], '\"')))
         return;                 /* no end-quote */
       vlen = endv - spos - klen - 1;
       *destination = malloc (vlen);
